@@ -4,7 +4,7 @@ use warnings;
 
 package Git::Wrapper;
 #ABSTRACT: Wrap git(7) command-line interface
-$Git::Wrapper::VERSION = '0.037';
+$Git::Wrapper::VERSION = '0.040';
 our $DEBUG=0;
 
 # Prevent ANSI color with extreme prejudice
@@ -310,21 +310,19 @@ sub _message_tempfile {
   return ( "file", '"'.$tmp->filename.'"' );
 }
 
-sub _munge_val {
+sub _opt_and_val {
   my( $name , $val ) = @_;
 
-  return $val eq '1'       ? ""
-    : length($name) == 1 ? $val
-      :                      "=$val";
-}
-
-sub _opt {
-  my $name = shift;
   $name =~ tr/_/-/;
-  return length($name) == 1
+  my $opt = length($name) == 1
     ? "-$name"
       : "--$name"
         ;
+
+  return
+      $val eq '1' ? ($opt)
+    : length($name) == 1 ? ($opt, $val)
+    :                      "$opt=$val";
 }
 
 sub _parse_args {
@@ -339,18 +337,18 @@ sub _parse_args {
       $stdin = delete $_->{-STDIN}
         if exists $_->{-STDIN};
 
-      for my $name ( keys %$_ ) {
+      for my $name ( sort keys %$_ ) {
         my $val = delete $_->{$name};
         next if $val eq '0';
 
         if ( $name =~ s/^-// ) {
-          push @pre_cmd , _opt( $name ) . _munge_val( $name , $val );
+          push @pre_cmd , _opt_and_val( $name , $val );
         }
         else {
           ( $name, $val ) = _message_tempfile( $val )
             if _win32_multiline_commit_msg( $cmd, $name, $val );
 
-          push @post_cmd , _opt( $name ) . _munge_val( $name , $val );
+          push @post_cmd , _opt_and_val( $name , $val );
         }
       }
     }
@@ -390,7 +388,7 @@ Git::Wrapper - Wrap git(7) command-line interface
 
 =head1 VERSION
 
-version 0.037
+version 0.040
 
 =head1 SYNOPSIS
 
@@ -414,7 +412,7 @@ argument passing, instead of CLI-style C<--options> as L<Git> does.
 
 Except as documented, every git subcommand is available as a method on a
 Git::Wrapper object. Replace any hyphens in the git command with underscores
-(for example, 'git init-db' would become C<$git->init_db>).
+(for example, C<git init-db> would become C<< $git->init_db >>).
 
 =head2 Method Arguments
 
@@ -458,7 +456,7 @@ invokes the command line
 
 I<N.b.> Because of the way arguments are parsed, should you need to pass an
 explicit '0' value to an option (for example, to have the same effect as
-C<--abrrev=0> on the command line), you should pass it with a leading space, like so:
+C<--abbrev=0> on the command line), you should pass it with a leading space, like so:
 
   $git->describe({ abbrev => ' 0' };
 
@@ -482,25 +480,83 @@ yourself before passing it to C<Git::Wrapper> methods.
 =head2 Error handling
 
 If a git command exits nonzero, a C<Git::Wrapper::Exception> object will be
-thrown (via C<die()>). These objects have three useful methods:
+thrown (via C<die>) and may be capture via C<eval> or L<Try::Tiny>, for
+example.
+
+The error object has three useful methods:
 
 =over
 
 =item * error
 
-error message
+Returns the full error message reported by the resulting git command sent to
+C<STDERR>. This method should not be used as a success/failure check, as
+C<git> will sometimes produce output on STDERR when a command is successful.
 
 =item * output
 
-normal output, as a single string
+Returns the full output generated by the git command that is sent to
+C<STDOUT>.  This method should not be used as a success/failure check, as
+C<git> will frequently not have any output with a successful command.
 
 =item * status
 
-the exit status
+Returns the non-zero exit code reported by git on error
 
 =back
 
-These exception objects stringify to the error message.
+=head3 Using Try::Tiny
+
+L<Try::Tiny> is the recommended way to catch exception objects thrown by
+L<Git::Wrapper>.
+
+  use Try::Tiny
+
+  my $git = Git::Wrapper->new('/path/to/my/repo');
+
+  try {
+    # equivalent to, "git --non-existent-option=1" on the commandline
+    $git->status({ "non-existent-option"=>1 });
+  }
+  catch {
+    # print STERR from erroneous git command
+    print $_->error;
+
+    # print STOUT from git command
+    print $_->output;
+
+    # print non-zero exist status of git processo
+    print $_->status;
+
+    # quotes are overloaded, so:
+    print "$_"; # equivalent to $_->error
+  };
+
+=head3 Using C<eval>
+
+If for some reason you are unable to use L<Try::Tiny>, it is also possible to use the C<eval> function to catch exception objects. B<THIS IS NOT RECOMMENDED!>
+
+  my $git = Git::Wrapper->new('/path/to/my/repo');
+
+  my $ok = eval {
+    # equivalent to, "git --non-existent-option=1" on the commandline
+    $git->status({ "non-existent-option"=>1 });
+    1;
+  };
+
+  if ($@ and ref $@ eq q{Git::Wrapper::Exception}) {
+    # print STERR from erroneous git command
+    print $@->error;
+
+    # print STOUT from git command
+    print $@->output;
+
+    # print non-zero exist status of git processo
+    print $@->status;
+
+    # quotes are overloaded, so:
+    print "$@"; # equivalent to $@->error
+  }
 
 =head1 METHODS
 
